Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/mma8452q_simpletest.py
    :caption: examples/mma8452q_simpletest.py
    :lines: 5-

Operation mode settings
------------------------

Example showing the Operation mode setting

.. literalinclude:: ../examples/mma8452q_operation_mode.py
    :caption: examples/mma8452q_operation_mode.py
    :lines: 5-

Scale range settings
---------------------

Example showing the Scale range setting

.. literalinclude:: ../examples/mma8452q_scale_range.py
    :caption: examples/mma8452q_scale_range.py
    :lines: 5-

Data rate settings
-------------------

Example showing the Data rate setting

.. literalinclude:: ../examples/mma8452q_data_rate.py
    :caption: examples/mma8452q_data_rate.py
    :lines: 5-

High pass filter cutoff settings
---------------------------------

Example showing the High pass filter cutoff setting

.. literalinclude:: ../examples/mma8452q_high_pass_filter_cutoff.py
    :caption: examples/mma8452q_high_pass_filter_cutoff.py
    :lines: 5-
